pub enum ArgType {
Float,
Enum(&'static [&'static str]),
Repeated {
typ: Box<ArgType>,
min: usize,
max: Option<usize>,
},
OneOf(Vec<ArgType>),
Optional(Box<ArgType>),
}Expand description
A function argument
Variants
Float
A floating point argument
Enum(&'static [&'static str])
A enum argument, the value can be any of the values
Repeated
A repeated argument
Fields
OneOf(Vec<ArgType>)
The argument can be one of the following types
Optional(Box<ArgType>)
Optional argument