pub enum Query {
Simple {
source: Source,
filters: Vec<Filter>,
aggregates: Vec<Aggregate>,
directives: Directives,
params: Params,
sample: Option<f64>,
},
Compute {
left: Box<Query>,
right: Box<Query>,
name: Metric,
op: ComputeFunction,
aggregates: Vec<Aggregate>,
directives: Directives,
params: Params,
},
}Expand description
A Query AST representing a query in the MPL language
Variants
Simple
A simple query that will produce a result
Fields

directives: DirectivesThe directives
Compute
A compute query taking the input of two queries and producing a by computing combined values
Fields

op: ComputeFunctionThe compute operation used to combine the left and right queries

directives: DirectivesThe directives
Implementations
Sourceimpl Query
impl Query
Sourcepub fn directives(&self) -> &Directives
pub fn directives(&self) -> &Directives
Get a ref to the directives of the query.