pub enum TimeError {
InvalidTimestamp(i64),
InvalidDuration(TryFromIntError),
}Expand description
An error that can occur when converting a time value.
Variants
InvalidTimestamp(i64)
Invalid timestamp could not be converted to a UTC datetime
InvalidDuration(TryFromIntError)
Invalid duration could not be converted to Duration as it exceeds the maximum i64