pub type Directives = HashMap<String, DirectiveValue>;Expand description
Directives given to adjust the behavior of the runtime
Aliased Type
pub struct Directives { /* private fields */ }pub type Directives = HashMap<String, DirectiveValue>;Directives given to adjust the behavior of the runtime
pub struct Directives { /* private fields */ }