pub struct Resolution(/* private fields */);Expand description
Resolution
Implementations
Sourceimpl Resolution
impl Resolution
Sourcepub fn as_timestamp(self) -> Timestamp
pub fn as_timestamp(self) -> Timestamp
Translates the resolution to a Timestamp.
Sourcepub fn as_idx(self) -> Result<u32, TryFromIntError>
pub fn as_idx(self) -> Result<u32, TryFromIntError>
trues to convert the secs into a u32 index
Sourcepub fn secs(s: u64) -> Result<Self, ResolutionError>
pub fn secs(s: u64) -> Result<Self, ResolutionError>
Creates a new Resolution from a number of seconds.
Sourcepub fn align_up_to(&self, align_up_to: Resolution) -> Self
pub fn align_up_to(&self, align_up_to: Resolution) -> Self
Aligns this resolution up to match the given Resolution.