pub struct Timestamp(pub u64);Expand description
Timestamp
Tuple Fields
0: u64Implementations
Sourceimpl Timestamp
impl Timestamp
Sourcepub fn is_multiple_of(self, other: Resolution) -> bool
pub fn is_multiple_of(self, other: Resolution) -> bool
Checks if the timestamp is a multiple of the given resolution.
Sourcepub fn as_idx(self) -> Result<u32, IndexError>
pub fn as_idx(self) -> Result<u32, IndexError>
trues to convert the secs into a u32 index
Sourcepub fn diff(self, other: Self) -> Option<Resolution>
pub fn diff(self, other: Self) -> Option<Resolution>
Returns the difference between two timestamps as a Resolution.
Returns None if the timestamps are equal.
Sourcepub fn align_down(self, resolution: Resolution) -> Self
pub fn align_down(self, resolution: Resolution) -> Self
Aligns the timestamp down to a given resolution.
Sourcepub fn align_up(self, resolution: Resolution) -> Self
pub fn align_up(self, resolution: Resolution) -> Self
Aligns the timestamp up to a given resolution.
Sourceimpl Timestamp
impl Timestamp
Sourcepub fn saturating_sub(self, rhs: Self) -> Self
pub fn saturating_sub(self, rhs: Self) -> Self
Saturating subtraction of two timestamps.