Parameterized

Enum Parameterized 

pub enum Parameterized<T> {
    Concrete(T),
    Param {
        span: SourceSpan,
        param: Param,
    },
}
A type that can either be concrete or a param.

Variants



Concrete(T)

A concrete type



Param

A parameter and the location where it’s used (for type checking)

Fields

span: SourceSpan

The location where the param is used

param: Param

The param

Implementations

Source

impl<T> Parameterized<T>

pub fn map_concrete<O, F: Fn(T) -> O>(self, f: F) -> Parameterized<O>

Map the concrete value.

pub fn try_map_concrete<O, E, F: Fn(T) -> Result<O, E>>( self, f: F, ) -> Result<Parameterized<O>, E>

Try to map the concrete value.

pub fn is_param(&self) -> bool

Returns true if the type is a param.

pub fn is_concrete(&self) -> bool

Returns true if the type is a concrete value.