Query

Enum Query 

pub enum Query {
    Simple {
        source: Source,
        filters: Vec<Filter>,
        aggregates: Vec<Aggregate>,
        directives: Directives,
        params: Params,
        sample: Option<f64>,
    },
    Compute {
        left: Box<Query>,
        right: Box<Query>,
        name: Metric,
        op: ComputeFunction,
        aggregates: Vec<Aggregate>,
        directives: Directives,
        params: Params,
    },
}
A Query AST representing a query in the MPL language

Variants



Simple

A simple query that will produce a result

Fields

source: Source

The source of the data

filters: Vec<Filter>

The filters to apply to the data

aggregates: Vec<Aggregate>

The aggregates to apply to the data

directives: Directives

The directives

params: Params

The params

sample: Option<f64>

How to sample series



Compute

A compute query taking the input of two queries and producing a by computing combined values

Fields

left: Box<Query>

The left hand side query to compute

right: Box<Query>

The right hand side query to compute

name: Metric

The name of the metric to produce

op: ComputeFunction

The compute operation used to combine the left and right queries

aggregates: Vec<Aggregate>

The aggregates to apply to the combined data

directives: Directives

The directives

params: Params

The params

Implementations

Source

impl Query

pub fn params(&self) -> &Params

Get a ref to the params of the query.

pub fn directives(&self) -> &Directives

Get a ref to the directives of the query.